@@ -2,8 +2,9 @@ package Sisimai;
 use feature ':5.10';
 use strict;
 use warnings;
+use Module::Load '';
 
-our $VERSION = '4.1.26';
+our $VERSION = '4.1.27';
 sub version { return $VERSION }
 sub sysname { 'bouncehammer'  }
 sub libname { 'Sisimai'       }
@@ -39,6 +40,24 @@ sub make {
     return $list;
 }
 
+sub dump {
+    # @Description  Wrapper method to parse mailbox/maidir and dump as JSON
+    # @Param <str>  (String) Path to mbox or Maildir/
+    # @Return       (String) JSON text
+    my $class = shift;
+    my $argv0 = shift // return undef;
+
+    my $parseddata = __PACKAGE__->make( $argv0 ) // [];
+    my $jsonobject = undef;
+    my $dumpedtext = undef;
+
+    # Dump as JSON
+    Module::Load::load( 'JSON', '-convert_blessed_universally' );
+    $jsonobject = JSON->new->allow_blessed->convert_blessed;
+
+    return $jsonobject->encode( $parseddata );
+}
+
 1;
 __END__
 
@@ -62,11 +81,13 @@ Japanese) and MAI (acronym of "Mail Analyzing Interface").
 
 =head1 BASIC USAGE
 
+=head2 C<B<make( I<'/path/to/mbox'> )>>
+
 C<make> method provides feature for getting parsed data from bounced email 
 messages like following.
 
     use Sisimai;
-    my $v = Sisimai->make( '/path/to/mbox' );   # or Path to Maildir
+    my $v = Sisimai->make('/path/to/mbox'); # or Path to Maildir
 
     if( defined $v ) {
         for my $e ( @$v ) {
@@ -78,6 +99,7 @@ messages like following.
             print $e->recipient->address;   # kijitora@example.jp   # To
             print $e->recipient->host;      # example.jp
             print $e->deliverystatus;       # 5.1.1
+            print $e->replycode;            # 550
             print $e->reason;               # userunknown
 
             my $h = $e->damn;               # Convert to HASH reference
@@ -92,10 +114,30 @@ messages like following.
         printf "%s\n", $json->encode( $v );
     }
 
+=head2 C<B<dump( I<'/path/to/mbox'> )>>
+C<dump> method provides feature to get parsed data from bounced email as JSON.
+
+    use Sisimai;
+    my $v = Sisimai->dump('/path/to/mbox'); # or Path to Maildir
+    print $v;                               # JSON string
+
 =head1 SEE ALSO
 
-L<Sisimai::Mail> - Mailbox or Maildir object
-L<Sisimai::Data> - Parsed data object
+=over
+
+=item L<Sisimai::Mail> - Mailbox or Maildir object
+
+=item L<Sisimai::Data> - Parsed data object
+
+=item L<https://tools.ietf.org/html/rfc3463> - RFC3463: Enhanced Mail System Status Codes
+
+=item L<https://tools.ietf.org/html/rfc3464> - RFC3464: An Extensible Message Format for Delivery Status Notifications
+
+=item L<https://tools.ietf.org/html/rfc5321> - RFC5321: Simple Mail Transfer Protocol
+
+=item L<https://tools.ietf.org/html/rfc5322> - RFC5322: Internet Message Format
+
+=back
 
 =head1 REPOSITORY
 
