@@ -19,7 +19,7 @@ my $rwaccessors = [
     'token',            # (String) Message token/MD5 Hex digest value
     'lhost',            # (String) local host name/Local MTA
     'rhost',            # (String) Remote host name/Remote MTA
-    'alias',            # (String) The value of alias(RHS)
+    'alias',            # (String) Alias of the recipient address
     'listid',           # (String) List-Id header of each ML
     'reason',           # (String) Bounce reason
     'action',           # (String) The value of Action: header
@@ -261,7 +261,11 @@ sub make {
 
             # The value of "Message-Id" header
             $p->{'messageid'} =  $rfc822data->{'message-id'} // '';
-            $p->{'messageid'} =~ y/<>//d if length $p->{'messageid'};
+            if( length $p->{'messageid'} ) {
+                # Remove angle brackets
+                $p->{'messageid'} =  $1 if $p->{'messageid'} =~ m/\A([^ ]+)[ ].*/;
+                $p->{'messageid'} =~ y/<>//d;
+            }
 
             # Cleanup the value of "Diagnostic-Code:" header
             $p->{'diagnosticcode'} =~ s/\s+$endofemail//;
