@@ -270,9 +270,9 @@ sub scan {
             }
         }
 
-        $e->{'spec'}    = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
-        $e->{'action'}  = 'failed' if $e->{'status'} =~ m/\A[45]/;
-        $e->{'agent'} ||= __PACKAGE__->smtpagent;
+        $e->{'spec'}   = $e->{'reason'} eq 'mailererror' ? 'X-UNIX' : 'SMTP';
+        $e->{'action'} = 'failed' if $e->{'status'} =~ m/\A[45]/;
+        $e->{'agent'}  = __PACKAGE__->smtpagent;
 
         delete $e->{'msexch'};
 
