@@ -279,6 +279,7 @@ my $StandardCode = {
         'notaccept'     => [ '4.3.2' ],
         'systemerror'   => [ '4.3.5' ],
         'networkerror'  => [ '4.4.2', '4.4.4', '4.4.6' ],
+        'toomanyconn'   => [ '4.4.5' ],
         'expired'       => [ '4.4.7', '4.4.1' ],
     },
     'permanent' => {
@@ -310,6 +311,7 @@ my $InternalCode = {
         'mailboxfull'   => [ '4.0.922' ],
         'exceedlimit'   => [ '4.0.923' ],
         'systemfull'    => [ '4.0.931' ],
+        'toomanyconn'   => [ '4.0.945' ],
         'expired'       => [ '4.0.947' ],
         'suspend'       => [ '4.0.990' ],
     },
@@ -326,13 +328,16 @@ my $InternalCode = {
         'notaccept'     => [ '5.0.932' ],
         'mesgtoobig'    => [ '5.0.934' ],
         'systemerror'   => [ '5.0.935' ],
+        'toomanyconn'   => [ '5.0.942' ],
         'networkerror'  => [ '5.0.946' ],
         'expired'       => [ '5.0.947' ],
         'contenterror'  => [ '5.0.960' ],
         'securityerror' => [ '5.0.970' ],
         'blocked'       => [ '5.0.971' ],
+        'spamdetected'  => [ '5.0.972' ],
         'suspend'       => [ '5.0.990' ],
         'mailererror'   => [ '5.0.991' ],
+        'norelaying'    => [ '5.0.992' ],
         'onhold'        => [ '5.0.999' ],
     },
 };
