@@ -8,7 +8,8 @@ sub match {
     my $class = shift;
     my $argvs = shift // return undef;
     my $regex = qr{(?>
-         message[ ](?:
+         improper[ ]use[ ]of[ ]8-bit[ ]data[ ]in[ ]message[ ]header
+        |message[ ](?:
              header[ ]size,[ ]or[ ]recipient[ ]list,[ ]exceeds[ ]policy[ ]limit
             |mime[ ]complexity[ ]exceeds[ ]the[ ]policy[ ]maximum
             )
