@@ -12,8 +12,13 @@ sub match {
         |could[ ]not[ ]find[ ]a[ ]gateway[ ]for
         |delivery[ ]time[ ]expired
         |giving[ ]up[ ]on
+        |it[ ]has[ ]not[ ]been[ ]collected[ ]after
+        |message[ ]expired[ ]after[ ]sitting[ ]in[ ]queue[ ]for
+        |Message[ ]timed[ ]out
         |retry[ ]time[ ]not[ ]reached[ ]for[ ]any[ ]host[ ]after[ ]a[ ]long[ ]failure[ ]period
+        |server[ ]did[ ]not[ ]respond
         |this[ ]message[ ]has[ ]been[ ]in[ ]the[ ]queue[ ]too[ ]long
+        |was[ ]not[ ]reachable[ ]within[ ]the[ ]allowed[ ]queue[ ]period
         )
     }ix;
 
