@@ -10,11 +10,13 @@ sub match {
     my $regex = qr{(?>
          because[ ]the[ ]recipient[ ]is[ ]only[ ]accepting[ ]mail[ ]from[ ]
             specific[ ]email[ ]addresses    # AOL Phoenix
+        |Bounced[ ]Address  # SendGrid|a message to an address has previously been Bounced.
         |due[ ]to[ ]extended[ ]inactivity[ ]new[ ]mail[ ]is[ ]not[ ]currently[ ]
             being[ ]accepted[ ]for[ ]this[ ]mailbox
         |has[ ]restricted[ ]SMS[ ]e-mail    # AT&T
         |http://postmaster[.]facebook[.]com/.+refused[ ]due[ ]to[ ]recipient[ ]preferences # Facebook
         |permanent[ ]failure[ ]for[ ]one[ ]or[ ]more[ ]recipients[ ][(].+:blocked[)]
+        |RESOLVER[.]RST[.]NotAuthorized # Microsoft Exchange
         |This[ ]account[ ]is[ ]protected[ ]by
         |user[ ](?:
              not[ ]found  # Filter on MAIL.RU
