@@ -37,6 +37,7 @@ sub list {
             MSP/US/Zoho.pm
         MTA.pm
             MTA/Activehunter.pm
+            MTA/ApacheJames.pm
             MTA/Courier.pm
             MTA/Domino.pm
             MTA/Exim.pm
@@ -72,19 +73,21 @@ sub list {
             Reason/MailerError.pm
             Reason/MesgTooBig.pm
             Reason/SpamDetected.pm
+            Reason/NoRelaying.pm
             Reason/NotAccept.pm
             Reason/NetworkError.pm
             Reason/OnHold.pm
             Reason/Rejected.pm
-            Reason/RelayingDenied.pm
             Reason/SecurityError.pm
             Reason/Suspend.pm
             Reason/SystemError.pm
             Reason/SystemFull.pm
+            Reason/TooManyConn.pm
             Reason/UserUnknown.pm
         RFC2606.pm
         RFC3463.pm
         RFC3464.pm
+        RFC5321.pm
         RFC5322.pm
         Rhost.pm
             Rhost/GoogleApps.pm
